package com.dayou.controller;

import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RestController;
import com.dayou.controller.BaseController;
import com.dayou.service.ICustomerService;
import com.dayou.entity.Customer;
import com.dayou.common.RestResponse;
import org.springframework.web.bind.annotation.*;
import com.dayou.common.PullDownModel;
import com.dayou.utils.ConvertUtil;
import com.dayou.utils.HttpKit;
import com.dayou.exception.ErrorCode;
import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.http.MediaType;
import org.springframework.web.multipart.MultipartFile;
/**
 * 客户表
 *
 * @author wucl
 * @since 2023-01-10
 */
@RestController
@RequestMapping("customer")
@Slf4j
public class CustomerController extends BaseController {
    @Autowired
    private ICustomerService customerService;

    /**
    * 客户表列表
    */
    @GetMapping("")
    public RestResponse<Page<Customer>> page(Customer customer, Page page){
        Page<Customer> pages=customerService.selectPage(page,customer);
        return RestResponse.data(pages);
    }

    /**
     * 客户表详情
     */
    @GetMapping("/{id}")
    public RestResponse<Customer> detail(@PathVariable Long id){
        Customer xCustomer =customerService.detail(id);
        return RestResponse.data(xCustomer);
     }

    /**
     * 客户表新增
     */
    @PostMapping("")
    public RestResponse<Boolean> save(@RequestBody Customer customer) {
        Boolean ret = customerService.add(customer);
        return RestResponse.data(ret);
    }

    /**
     * 客户表更新
     */
    @PutMapping("")
    public RestResponse<Boolean> update(@RequestBody Customer customer) {
        Boolean ret = customerService.update(customer);
        return RestResponse.data(ret);
    }

    /**
     * 客户表删除
     */
    @DeleteMapping("/{id}")
    public RestResponse<Boolean> delete(@PathVariable Long id) {
        Boolean ret = customerService.delete(id);
        return RestResponse.data(ret);
    }


    /**
     * 客户表下拉列表
     */
    @GetMapping("/simpleAll")
    public RestResponse<List<PullDownModel>> simpleAll(){
        LambdaQueryWrapper<Customer> lambdaQueryWrapper = new LambdaQueryWrapper<Customer>()
        .select(Customer::getId,Customer::getName)
        .eq(Customer::getDeleted,false);
        List<Customer> list= customerService.list(lambdaQueryWrapper);
        List<PullDownModel> ret=ConvertUtil.copyList(list, PullDownModel.class);
        return RestResponse.data(ret);
    }
}

